@@ -482,7 +482,7 @@ class ExcelReader(ExcelAgent):
         data = self._apply_ignore_rows_columns(
             data, ignore_rows, ignore_columns, nw_row, nw_col, sym_name
         )
-        if len(data) == 0:
+        if data.size == 0:
             self._write(None, sym_name, sym_type, rdim, cdim)
             return
         # if data.shape[0] < required_rows - len(ignore_rows):
